@@ -6,7 +6,7 @@ use warnings;
 use Hash::Util qw(lock_hash unlock_value lock_value);
 use Carp qw(confess);
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =pod
 
@@ -65,14 +65,20 @@ A boolean (in Perl terms) if CLI is running in debug mode.
 
 A string identifying the chosen language for processing.
 
+=item 8
+
+An optional string of a regular expression to match the content of the
+translated properties.
+
 =back
 
 =cut
 
 sub new {
-    my ( $class, $source_dir, $target_dir, $use_counter,
-        $is_remove, $is_add, $is_debug, $lang )
-        = @_;
+    my (
+        $class,  $source_dir, $target_dir, $use_counter, $is_remove,
+        $is_add, $is_debug,   $lang,       $search
+    ) = @_;
     my $self = {
         source_dir  => $source_dir,
         target_dir  => $target_dir,
@@ -92,11 +98,45 @@ sub new {
     confess
 'Removing or adding translation files are excluding operations, they cannot be both true at the same time'
         if ( $is_remove and $is_add );
+
+    if ( defined($search) ) {
+        $self->{search}     = qr/$search/;
+        $self->{has_search} = 1;
+    }
+    else {
+        $self->{has_search} = 0;
+    }
+
     bless $self, $class;
     lock_hash( %{$self} );
     return $self;
 }
 
+=head2 is_to_search
+
+Returns true (1) or false (0) if there is a defined term to search on the
+translated properties values.
+
+=cut
+
+sub is_to_search {
+    my $self = shift;
+    return $self->{has_search};
+}
+
+=head2 search_term
+
+Returns the compiled regular expression that will be used to match terms in the
+translated properties values.
+
+=cut
+
+sub search_term {
+    my $self = shift;
+    confess 'There is no defined search term' unless ( $self->{has_search} );
+    return $self->{search};
+}
+
 =head2 get_language
 
 Returns a string identifying the chosen language for processing.
